@@ -6,18 +6,24 @@
   are the bottleneck of web servers.
 -}
 
-module Network.Sendfile (sendfile, FileRange(..)) where
+module Network.Sendfile (
+    sendfile
+  , sendfileWithHeader
+#if OS_BSD || OS_MacOS || OS_Linux
+  , sendfileFd
+  , sendfileFdWithHeader
+#endif
+  , FileRange(..)
+  ) where
 
 import Network.Sendfile.Types
 
 #ifdef OS_BSD
 import Network.Sendfile.BSD
 #elif  OS_MacOS
-import Network.Sendfile.MacOS
+import Network.Sendfile.BSD
 #elif  OS_Linux
 import Network.Sendfile.Linux
-#elif  OS_Windows
-import Network.Sendfile.Windows
 #else
 import Network.Sendfile.Fallback
 #endif
