@@ -1,3 +1,4 @@
+{-# LANGUAGE BangPatterns #-}
 {-# LANGUAGE CPP #-}
 {-# LANGUAGE OverloadedStrings #-}
 
@@ -8,6 +9,7 @@ import Control.Exception
 import Control.Monad
 import Control.Monad.Trans.Resource (MonadResource, runResourceT)
 import Data.ByteString.Char8 as BS
+import qualified Data.ByteString.Lazy as BL
 import Data.Conduit
 import Data.Conduit.Binary as CB
 import Data.Conduit.List as CL
@@ -16,11 +18,9 @@ import Data.IORef
 import Network.Sendfile
 import Network.Socket
 import System.Directory
-import System.Exit
 import System.IO
-import System.Posix.Files
-import System.Process
 import System.Timeout
+import System.EasyFile
 import Test.Hspec
 
 ----------------------------------------------------------------
@@ -29,28 +29,34 @@ spec :: Spec
 spec = do
     describe "sendfile" $ do
         it "sends an entire file" $ do
-            sendFile EntireFile `shouldReturn` ExitSuccess
+            sendFile EntireFile `shouldReturn` True
         it "sends a part of file" $ do
-            sendFile (PartOfFile 2000 1000000) `shouldReturn` ExitSuccess
+            sendFile (PartOfFile 2000 1000000) `shouldReturn` True
         it "terminates even if length is over" $ do
             shouldTerminate $ sendIllegal (PartOfFile 2000 5000000)
         it "terminates even if offset is over" $ do
             shouldTerminate $ sendIllegal (PartOfFile 5000000 6000000)
+        -- On Windows, setFileSize throws an exception due to the
+        -- access permission. The test case will be finished but it is
+        -- not a right test.
         it "terminates even if the file is truncated" $ do
             shouldTerminate truncateFile
     describe "sendfileWithHeader" $ do
         it "sends an header and an entire file" $ do
-            sendFileH EntireFile `shouldReturn` ExitSuccess
+            sendFileH EntireFile `shouldReturn` True
         it "sends an header and a part of file" $ do
-            sendFileH (PartOfFile 2000 1000000) `shouldReturn` ExitSuccess
+            sendFileH (PartOfFile 2000 1000000) `shouldReturn` True
         it "sends a large header and an entire file" $ do
-            sendFileHLarge EntireFile `shouldReturn` ExitSuccess
+            sendFileHLarge EntireFile `shouldReturn` True
         it "sends a large header and a part of file" $ do
-            sendFileHLarge (PartOfFile 2000 1000000) `shouldReturn` ExitSuccess
+            sendFileHLarge (PartOfFile 2000 1000000) `shouldReturn` True
         it "terminates even if length is over" $ do
             shouldTerminate $ sendIllegalH (PartOfFile 2000 5000000)
         it "terminates even if offset is over" $ do
             shouldTerminate $ sendIllegalH (PartOfFile 5000000 6000000)
+        -- On Windows, setFileSize throws an exception due to the
+        -- access permission. The test case will be finished but it is
+        -- not a right test.
         it "terminates even if the file is truncated" $ do
             shouldTerminate truncateFileH
   where
@@ -59,10 +65,10 @@ spec = do
 
 ----------------------------------------------------------------
 
-sendFile :: FileRange -> IO ExitCode
+sendFile :: FileRange -> IO Bool
 sendFile range = sendFileCore range []
 
-sendFileH :: FileRange -> IO ExitCode
+sendFileH :: FileRange -> IO Bool
 sendFileH range = sendFileCore range headers
   where
     headers = [
@@ -74,7 +80,7 @@ sendFileH range = sendFileCore range headers
       , "\n"
       ]
 
-sendFileHLarge :: FileRange -> IO ExitCode
+sendFileHLarge :: FileRange -> IO Bool
 sendFileHLarge range = sendFileCore range headers
   where
     headers = [
@@ -86,7 +92,7 @@ sendFileHLarge range = sendFileCore range headers
       , "\n"
       ]
 
-sendFileCore :: FileRange -> [ByteString] -> IO ExitCode
+sendFileCore :: FileRange -> [ByteString] -> IO Bool
 sendFileCore range headers = bracket setup teardown $ \(s2,_) -> do
 #if MIN_VERSION_conduit(1,3,0)
     runResourceT $ runConduit (sourceSocket s2 .| sinkFile outputFile)
@@ -94,7 +100,9 @@ sendFileCore range headers = bracket setup teardown $ \(s2,_) -> do
     runResourceT $ sourceSocket s2 $$ sinkFile outputFile
 #endif
     runResourceT $ copyfile range
-    system $ "cmp -s " ++ outputFile ++ " " ++ expectedFile
+    !f1 <- BL.readFile outputFile
+    !f2 <- BL.readFile expectedFile
+    return $! (f1 == f2)
   where
     copyfile EntireFile = do
         -- of course, we can use <> here
@@ -133,8 +141,8 @@ sendFileCore range headers = bracket setup teardown $ \(s2,_) -> do
         killThread tid
         removeFileIfExists outputFile
         removeFileIfExists expectedFile
-    inputFile = "test/inputFile"
-    outputFile = "test/outputFile"
+    inputFile    = "test/inputFile"
+    outputFile   = "test/outputFile"
     expectedFile = "test/expectedFile"
 
 ----------------------------------------------------------------
@@ -176,7 +184,7 @@ sendIllegalCore range headers = bracket setup teardown $ \(s2,_) -> do
         close s2
         killThread tid
         removeFileIfExists outputFile
-    inputFile = "test/inputFile"
+    inputFile  = "test/inputFile"
     outputFile = "test/outputFile"
 
 ----------------------------------------------------------------
@@ -229,8 +237,8 @@ truncateFileCore headers = bracket setup teardown $ \(s2,_) -> do
         killThread tid
         removeFileIfExists tempFile
         removeFileIfExists outputFile
-    inputFile = "test/inputFile"
-    tempFile = "test/tempFile"
+    inputFile  = "test/inputFile"
+    tempFile   = "test/tempFile"
     outputFile = "test/outputFile"
     range = EntireFile
 
